Concept

Enum Concept 

pub enum Concept {
Show 19 variants Lit, Class, Alt, Group, Seq, Use, Until, Times, Optional, Name, Regex, Min, Max, Digit, Alpha, Space, Word, Any, Eol,
}
与语言无关的内部语义。任何书写形式都先映射到它,再由它驱动编译。

Variants



Lit

字面量:字面 / lit



Class

字符类: / class



Alt

选择:任一 / alt



Group

内联组: / group



Seq

序列:序列 / seq



Use

引用另一规则: / use



Until

推进直到:直到 / until



Times

量词: / times



Optional

可选:可选 / optional



Name

命名捕获: / name



Regex

regex 逃生舱:正则 / regex



Min

最小 / min



Max

最大 / max



Digit

数字 / digit



Alpha

字母 / alpha(含汉字)



Space

空白 / space



Word

/ word



Any

任意 / any



Eol

行尾 / eol